==> antlrworks-1.1.7-src.zip: src/plugin/org/antlr/works/plugin/intellij/PIApplicationComponent.java <==
package org.antlr.works.plugin.intellij;

import com.intellij.openapi.actionSystem.ActionManager;
import com.intellij.openapi.actionSystem.Anchor;
import com.intellij.openapi.actionSystem.Constraints;
import com.intellij.openapi.actionSystem.DefaultActionGroup;
import com.intellij.openapi.components.ApplicationComponent;
import com.intellij.openapi.fileTypes.FileTypeManager;
import com.intellij.openapi.options.Configurable;
import com.intellij.openapi.options.ConfigurationException;
import org.antlr.works.IDE;
import org.antlr.works.plugin.container.PCXJApplicationDelegate;
import org.antlr.works.plugin.container.PCXJApplicationInterface;
import org.antlr.works.prefs.AWPrefsDialog;
import org.antlr.works.utils.IconManager;
import org.antlr.xjlib.appkit.app.XJApplication;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

/*

[The "BSD licence"]
Copyright (c) 2005-2006 Jean Bovet
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

public class PIApplicationComponent implements ApplicationComponent, Configurable {

    private AWPrefsDialog prefsDialog;

    public PIApplicationComponent() {
        IDE._isPlugin = true;
    }

    public void initComponent() {
        XJApplication.setDelegate(new PCXJApplicationDelegate());
        XJApplication.setPropertiesPath(IDE.PROPERTIES_PATH);
        XJApplication.setShared(new PCXJApplicationInterface(null));

        FileTypeManager.getInstance().registerFileType(new PIFileType(), new String[] { "g" });

        PIActionNewFile action = new PIActionNewFile();
        ActionManager.getInstance().registerAction("NewGrammarFile", action);
        DefaultActionGroup group = (DefaultActionGroup) ActionManager.getInstance().getAction("NewGroup");
        group.add(action, new Constraints(Anchor.AFTER, "NewFile"));
    }

    public void disposeComponent() {
    }

    @NotNull
    public String getComponentName() {
        return "AWApplicationComponent";
    }

    // ********* Configurable *************

    public String getDisplayName() {
        return "ANTLRWorks";
    }

    public Icon getIcon() {
        return IconManager.shared().getIconApplication32x32();
    }

    public String getHelpTopic() {
        return null;
    }

    public JComponent createComponent() {
        prefsDialog = new AWPrefsDialog();
        prefsDialog.becomingVisibleForTheFirstTime();
        return prefsDialog.getComponent();
    }

    public boolean isModified() {
        return true;
    }

    public void apply() throws ConfigurationException {
        prefsDialog.apply();
    }

    public void reset() {
    }

    public void disposeUIResources() {
        prefsDialog.close();
        prefsDialog = null;
    }
}

==> antlrworks-1.2.2-src.zip: src/plugin/org/antlr/works/plugin/intellij/PIApplicationComponent.java <==
package org.antlr.works.plugin.intellij;

import com.intellij.openapi.actionSystem.ActionManager;
import com.intellij.openapi.actionSystem.Anchor;
import com.intellij.openapi.actionSystem.Constraints;
import com.intellij.openapi.actionSystem.DefaultActionGroup;
import com.intellij.openapi.components.ApplicationComponent;
import com.intellij.openapi.fileTypes.FileTypeManager;
import com.intellij.openapi.options.Configurable;
import com.intellij.openapi.options.ConfigurationException;
import org.antlr.works.IDE;
import org.antlr.works.dialog.AWPrefsDialog;
import org.antlr.works.plugin.container.PCXJApplicationDelegate;
import org.antlr.works.utils.IconManager;
import org.antlr.xjlib.appkit.app.XJApplication;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

/*

[The "BSD licence"]
Copyright (c) 2005-2006 Jean Bovet
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

public class PIApplicationComponent implements ApplicationComponent, Configurable {

    private AWPrefsDialog prefsDialog;

    public PIApplicationComponent() {
        IDE._isPlugin = true;
    }

    public void initComponent() {
        XJApplication.setDelegate(new PCXJApplicationDelegate());
        XJApplication.setPropertiesPath(IDE.PROPERTIES_PATH);

        FileTypeManager.getInstance().registerFileType(new PIFileType(), "g");

        PIActionNewFile action = new PIActionNewFile();
        ActionManager.getInstance().registerAction("NewGrammarFile", action);
        DefaultActionGroup group = (DefaultActionGroup) ActionManager.getInstance().getAction("NewGroup");
        group.add(action, new Constraints(Anchor.AFTER, "NewFile"));
    }

    public void disposeComponent() {
    }

    @NotNull
    public String getComponentName() {
        return "AWApplicationComponent";
    }

    // ********* Configurable *************

    public String getDisplayName() {
        return "ANTLRWorks";
    }

    public Icon getIcon() {
        return IconManager.shared().getIconApplication32x32();
    }

    public String getHelpTopic() {
        return null;
    }

    public JComponent createComponent() {
        prefsDialog = new AWPrefsDialog();
        prefsDialog.becomingVisibleForTheFirstTime();
        return prefsDialog.getComponent();
    }

    public boolean isModified() {
        return true;
    }

    public void apply() throws ConfigurationException {
        prefsDialog.apply();
    }

    public void reset() {
    }

    public void disposeUIResources() {
        prefsDialog.close(false);
        prefsDialog = null;
    }
}
